Contour Operations
=============================

This section encompasses a set of functions tailored for operations on contours. 

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   functions/contour_operations/approximate_circle_by_area
   functions/contour_operations/circularity
   functions/contour_operations/get_center
   functions/contour_operations/roundness
